@@ -134,7 +134,7 @@ $actions{clean} = sub ($) {
   my ($dbh) = @_;
   my $sql = "DELETE FROM graylist WHERE NOT ts_ok IS NULL AND " .
             "ts_entry + $config{delay_permit} > ts_latest AND " .
-            "now() - $config{delay_halfopen} >= ts_entry";
+            "now() - $config{delay_halfopen} >= ts_entry AND NOT ip = '::'";
   $dbh->do($sql);
 };
 
