@@ -167,10 +167,11 @@ sub graypol_check ($$) {
     my $from = lc($params->{sender});
     my $to = lc($params->{recipient});
 
-    $ok = _graypol_check($sth, $params, "::", $from, $to, 0) ||
-          _graypol_check($sth, $params,
+    $ok = _graypol_check($sth, $params,
                          normalize_ip(lc($params->{client_address})),
-                         $from, $to, 1);
+                         $from, $to, 1) ||
+          _graypol_check($sth, $params, "::", "",    $to, 0) ||
+          _graypol_check($sth, $params, "::", $from, $to, 0);
   }
 
   return $ok;
